@@ -313,6 +313,12 @@ static const struct log_info_cat internal_cat[OSMO_NUM_DLIB] = {
 		.enabled = 1, .loglevel = LOGL_NOTICE,
 		.color = "\033[38;5;11m",
 	},
+	[INT2IDX(DLIO)] = {
+		.name = "DLIO",
+		.description = "libosmocore IO Subsystem",
+		.enabled = 1, .loglevel = LOGL_NOTICE,
+		.color = "\033[38;5;67m",
+	},
 };
 
 void assert_loginfo(const char *src)
@@ -1161,6 +1167,7 @@ int log_target_file_switch_to_stream(struct log_target *target)
 	if (target->type == LOG_TGT_TYPE_FILE) {
 		osmo_fd_unregister(&wq->bfd);
 		close(wq->bfd.fd);
+		wq->bfd.fd = -1;
 	}
 
 	/* release the queue itself */
@@ -1328,11 +1335,11 @@ void log_target_destroy(struct log_target *target)
 		wq = target->tgt_file.wqueue;
 		if (wq) {
 			if (wq->bfd.fd >= 0) {
+				osmo_fd_unregister(&wq->bfd);
 				if (target->type == LOG_TGT_TYPE_FILE)
 					close(wq->bfd.fd);
 				wq->bfd.fd = -1;
 			}
-			osmo_fd_unregister(&wq->bfd);
 			osmo_wqueue_clear(wq);
 			talloc_free(wq);
 			target->tgt_file.wqueue = NULL;
@@ -1375,8 +1382,8 @@ int log_target_file_reopen(struct log_target *target)
 			return -errno;
 	} else {
 		wq = target->tgt_file.wqueue;
-		osmo_fd_unregister(&wq->bfd);
 		if (wq->bfd.fd >= 0) {
+			osmo_fd_unregister(&wq->bfd);
 			close(wq->bfd.fd);
 			wq->bfd.fd = -1;
 		}
